@@ -58,9 +58,13 @@ clean <- function(setwd = NULL, source = c(), load = c(), clearPkgs = FALSE) {
   erase() #clear console
   rm(list = setdiff(ls(envir = parent.frame(),all.names = TRUE),
                     c("setwd", "source", "load", "clearPkgs")), envir = parent.frame())
-  if(.Device !="null device" | length(grDevices::dev.list())) graphics.off() #graphics off
-  closeAllConnections() #close any open connections
-  gc() #garbage cleanup to free memory
+  #graphics off
+  if(.Device !="null device" | length(grDevices::dev.list())) graphics.off()
+  #close any open connections
+  options(NULL)
+  close(file())
+  #garbage cleanup to free memory
+  gc()
 
 
   # set directory if it exists
